@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -32,7 +32,11 @@ import docking.widgets.table.RowFilterTransformer;
 import ghidra.app.plugin.core.symtable.AbstractSymbolTableModel.OriginalNameColumn;
 import ghidra.framework.options.SaveState;
 import ghidra.framework.plugintool.PluginTool;
+import ghidra.program.model.address.Address;
+import ghidra.program.model.listing.Program;
 import ghidra.program.model.symbol.Symbol;
+import ghidra.program.model.symbol.SymbolTable;
+import ghidra.program.util.ProgramLocation;
 import ghidra.util.table.*;
 
 class SymbolPanel extends JPanel {
@@ -41,9 +45,9 @@ class SymbolPanel extends JPanel {
 
 	private static final String FILTER_SETTINGS_ELEMENT_NAME = "FILTER_SETTINGS";
 
-	private SymbolProvider symProvider;
-	private SymbolTableModel tableModel;
-	private GhidraTable symTable;
+	private SymbolProvider symbolProvider;
+	private SymbolTableModel symbolModel;
+	private GhidraTable gTable;
 	private TableModelListener listener;
 	private FilterDialog filterDialog;
 	private GhidraThreadedTablePanel<SymbolRowObject> threadedTablePanel;
@@ -51,34 +55,31 @@ class SymbolPanel extends JPanel {
 
 	SymbolPanel(SymbolProvider provider, SymbolTableModel model, SymbolRenderer renderer,
 			PluginTool tool) {
-
 		super(new BorderLayout());
 
-		this.symProvider = provider;
-		this.tableModel = model;
+		this.symbolProvider = provider;
+		this.symbolModel = model;
+		this.threadedTablePanel = new GhidraThreadedTablePanel<>(model);
+		this.listener = e -> symbolProvider.updateTitle();
 
-		threadedTablePanel = new GhidraThreadedTablePanel<>(model);
-
-		this.listener = e -> symProvider.updateTitle();
-
-		symTable = threadedTablePanel.getTable();
-		symTable.setAutoLookupColumn(AbstractSymbolTableModel.LABEL_COL);
-		symTable.setRowSelectionAllowed(true);
-		symTable.setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
-		symTable.getModel().addTableModelListener(listener);
-		symTable.getSelectionModel().addListSelectionListener(e -> {
+		gTable = threadedTablePanel.getTable();
+		gTable.setAutoLookupColumn(AbstractSymbolTableModel.LABEL_COL);
+		gTable.setRowSelectionAllowed(true);
+		gTable.setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
+		gTable.getModel().addTableModelListener(listener);
+		gTable.getSelectionModel().addListSelectionListener(e -> {
 			if (!e.getValueIsAdjusting()) {
 				handleTableSelection();
-				tool.contextChanged(symProvider);
+				tool.contextChanged(symbolProvider);
 			}
 		});
 
-		symTable.setAccessibleNamePrefix("Symbol");
+		gTable.setAccessibleNamePrefix("Symbol");
 
-		symTable.installNavigation(tool);
+		gTable.installNavigation(tool);
 
-		for (int i = 0; i < symTable.getColumnCount(); i++) {
-			TableColumn column = symTable.getColumnModel().getColumn(i);
+		for (int i = 0; i < gTable.getColumnCount(); i++) {
+			TableColumn column = gTable.getColumnModel().getColumn(i);
 			column.setCellRenderer(renderer);
 			if (column.getModelIndex() == AbstractSymbolTableModel.LABEL_COL) {
 				column.setCellEditor(new SymbolEditor());
@@ -91,11 +92,11 @@ class SymbolPanel extends JPanel {
 		filterDialog = new FilterDialog(tool);
 
 		// enable dragging symbols out of the symbol table
-		new SymbolTableDragProvider(symTable, model);
+		new SymbolTableDragProvider(gTable, model);
 	}
 
 	private JPanel createFilterFieldPanel() {
-		tableFilterPanel = new GhidraTableFilterPanel<>(symTable, tableModel);
+		tableFilterPanel = new GhidraTableFilterPanel<>(gTable, symbolModel);
 		tableFilterPanel.setToolTipText("Filters the contents of the table on symbol " +
 			"names that start with the given pattern");
 
@@ -120,17 +121,35 @@ class SymbolPanel extends JPanel {
 		return tableFilterPanel;
 	}
 
-	protected RowFilterTransformer<SymbolRowObject> updateRowDataTransformer(boolean nameOnly) {
-		TableColumnModel columnModel = symTable.getColumnModel();
-		if (nameOnly) {
-			return new NameOnlyRowTransformer(tableModel, columnModel);
+	void locationChanged(ProgramLocation location) {
+
+		Program program = location.getProgram();
+		SymbolTable symbolTable = program.getSymbolTable();
+		Address address = location.getAddress();
+		Symbol primarySymbol = symbolTable.getPrimarySymbol(address);
+		if (primarySymbol == null) {
+			return;
 		}
-		return new DefaultRowFilterTransformer<>(tableModel, columnModel);
+
+		SymbolRowObject rowObject = new SymbolRowObject(primarySymbol);
+		int index = symbolModel.getRowIndex(rowObject);
+		if (index >= 0) {
+			gTable.selectRow(index);
+			gTable.scrollToSelectedRow();
+		}
+	}
+
+	protected RowFilterTransformer<SymbolRowObject> updateRowDataTransformer(boolean nameOnly) {
+		TableColumnModel columnModel = gTable.getColumnModel();
+		if (nameOnly) {
+			return new NameOnlyRowTransformer(symbolModel, columnModel);
+		}
+		return new DefaultRowFilterTransformer<>(symbolModel, columnModel);
 	}
 
 	void dispose() {
-		symTable.getModel().removeTableModelListener(listener);
-		symTable.dispose();
+		gTable.getModel().removeTableModelListener(listener);
+		gTable.dispose();
 		threadedTablePanel.dispose();
 		tableFilterPanel.dispose();
 		filterDialog.dispose();
@@ -140,24 +159,24 @@ class SymbolPanel extends JPanel {
 		if (filterDialog == null) {
 			return;
 		}
-		if (symTable.isEditing()) {
-			symTable.editingCanceled(null);
+		if (gTable.isEditing()) {
+			gTable.editingCanceled(null);
 		}
-		symProvider.setCurrentSymbol(null);
-		symTable.clearSelection();
+		symbolProvider.setCurrentSymbol(null);
+		gTable.clearSelection();
 
-		filterDialog.adjustFilter(symProvider, tableModel);
+		filterDialog.adjustFilter(symbolProvider, symbolModel);
 	}
 
 	SymbolFilter getFilter() {
-		return tableModel.getFilter();
+		return symbolModel.getFilter();
 	}
 
 	void readConfigState(SaveState saveState) {
 		Element filterElement = saveState.getXmlElement(FILTER_SETTINGS_ELEMENT_NAME);
 		if (filterElement != null) {
 			filterDialog.restoreFilter(filterElement);
-			tableModel.setFilter(filterDialog.getFilter());
+			symbolModel.setFilter(filterDialog.getFilter());
 		}
 	}
 
@@ -167,26 +186,26 @@ class SymbolPanel extends JPanel {
 	}
 
 	private void handleTableSelection() {
-		int selectedRowCount = symTable.getSelectedRowCount();
+		int selectedRowCount = gTable.getSelectedRowCount();
 
 		if (selectedRowCount == 1) {
-			int selectedRow = symTable.getSelectedRow();
-			Symbol symbol = symProvider.getSymbolForRow(selectedRow);
-			symProvider.setCurrentSymbol(symbol); // null allowed
+			int selectedRow = gTable.getSelectedRow();
+			Symbol symbol = symbolProvider.getSymbolForRow(selectedRow);
+			symbolProvider.setCurrentSymbol(symbol); // null allowed
 		}
 		else {
-			symProvider.setCurrentSymbol(null);
+			symbolProvider.setCurrentSymbol(null);
 		}
 	}
 
 	int getActualSymbolCount() {
-		return symTable.getRowCount();
+		return gTable.getRowCount();
 	}
 
 	List<Symbol> getSelectedSymbols() {
 		List<Symbol> list = new ArrayList<>();
-		int[] rows = symTable.getSelectedRows();
-		for (SymbolRowObject rowObject : tableModel.getRowObjects(rows)) {
+		int[] rows = gTable.getSelectedRows();
+		for (SymbolRowObject rowObject : symbolModel.getRowObjects(rows)) {
 			Symbol s = rowObject.getSymbol();
 			if (s != null) {
 				list.add(s);
@@ -196,7 +215,7 @@ class SymbolPanel extends JPanel {
 	}
 
 	GhidraTable getTable() {
-		return symTable;
+		return gTable;
 	}
 
 //==================================================================================================
