@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -19,6 +19,8 @@ import java.io.IOException;
 import java.util.Collection;
 import java.util.List;
 
+import org.apache.commons.io.FilenameUtils;
+
 import ghidra.app.util.Option;
 import ghidra.app.util.bin.ByteProvider;
 import ghidra.app.util.importer.MessageLog;
@@ -59,6 +61,52 @@ public interface Loader extends ExtensionPoint, Comparable<Loader> {
 	public static boolean loggingDisabled =
 		SystemUtilities.getBooleanProperty("disable.loader.logging", false);
 
+	/**
+	 * A {@link Loader} configuration
+	 * 
+	 * @param provider The bytes to load.
+	 * @param importName The name for the primary {@link Loaded} {@link DomainObject}. Path 
+	 *   information that appears at the beginning the name will be appended to the 
+	 *   {@code projectRootPath} during the {@link LoadResults#save(TaskMonitor) saving process}.
+	 * @param project The {@link Project}. Loaders can use this to take advantage of existing
+	 *   {@link DomainFolder}s and {@link DomainFile}s to do custom behaviors such as loading
+	 *   libraries. A {@link Project} is also required during the 
+	 *   {@link LoadResults#save(TaskMonitor) saving process}. Could be {@code null} if there is no
+	 *   project.
+	 * @param projectRootPath The project folder path that all {@link Loaded} {@link DomainObject}s
+	 *   will be {@link LoadResults#save(TaskMonitor) saved} relative to. If {@code null}, "/" will 
+	 *   be used.
+	 * @param mirrorFsLayout True if the filesystem layout should be mirrored when 
+	 *   {@link LoadResults#save(TaskMonitor) saving}; otherwise, false
+	 * @param loadSpec The {@link LoadSpec} to use during load.
+	 * @param options The load options.
+	 * @param consumer A reference to the object "consuming" the returned {@link LoadResults}, used
+	 *   to ensure the underlying {@link Program}s are only closed when every consumer is done
+	 *   with it (see {@link LoadResults#close()}).
+	 * @param log The message log.
+	 * @param monitor A task monitor.
+	 */
+	public record ImporterSettings(ByteProvider provider, String importName, Project project,
+			String projectRootPath, boolean mirrorFsLayout, LoadSpec loadSpec, List<Option> options,
+			Object consumer, MessageLog log, TaskMonitor monitor) {
+
+		/**
+		 * {@return The name portion of the {@code importName}, stripping off any leading path
+		 * information that may be present}
+		 */
+		public String importNameOnly() {
+			return FilenameUtils.getName(importName);
+		}
+
+		/**
+		 * {@return The path portion of the {@code importName} if present, stripping off the
+		 * trailing name (could be the empty string)}
+		 */
+		public String importPathOnly() {
+			return FilenameUtils.getFullPath(importName);
+		}
+	}
+
 	/**
 	 * If this {@link Loader} supports loading the given {@link ByteProvider}, this methods returns
 	 * a {@link Collection} of all supported {@link LoadSpec}s that contain discovered load 
@@ -83,30 +131,12 @@ public interface Loader extends ExtensionPoint, Comparable<Loader> {
 	 * <p>
 	 * Note that when the load completes, the returned {@link Loaded} {@link DomainObject}s are not 
 	 * saved to a project.  That is the responsibility of the caller (see 
-	 * {@link LoadResults#save(Project, Object, MessageLog, TaskMonitor)}).
+	 * {@link LoadResults#save(TaskMonitor)}).
 	 * <p>
-	 * It is also the responsibility of the caller to release the returned {@link Loaded} 
-	 * {@link DomainObject}s with {@link LoadResults#release(Object)} when they are no longer
-	 * needed.
+	 * It is also the responsibility of the caller to close the returned {@link Loaded}
+	 * {@link DomainObject}s with {@link LoadResults#close()} when they are no longer needed.
 	 *
-	 * @param provider The bytes to load.
-	 * @param loadedName A suggested name for the primary {@link Loaded} {@link DomainObject}. 
-	 *   This is just a suggestion, and a {@link Loader} implementation reserves the right to change
-	 *   it. The {@link LoadResults} should be queried for their true names using 
-	 *   {@link Loaded#getName()}.
-	 * @param project The {@link Project}.  Loaders can use this to take advantage of existing
-	 *   {@link DomainFolder}s and {@link DomainFile}s to do custom behaviors such as loading
-	 *   libraries. Could be null if there is no project.
-	 * @param projectFolderPath A suggested project folder path for the {@link Loaded} 
-	 *   {@link DomainObject}s. This is just a suggestion, and a {@link Loader} implementation 
-	 *   reserves the right to change it for each {@link Loaded} result. The {@link LoadResults} 
-	 *   should be queried for their true project folder paths using 
-	 *   {@link Loaded#getProjectFolderPath()}.
-	 * @param loadSpec The {@link LoadSpec} to use during load.
-	 * @param options The load options.
-	 * @param messageLog The message log.
-	 * @param consumer A consumer object for generated {@link DomainObject}s.
-	 * @param monitor A task monitor.
+	 * @param settings The {@link ImporterSettings}.
 	 * @return The {@link LoadResults} which contains one or more {@link Loaded} 
 	 *   {@link DomainObject}s (created but not saved).
 	 * @throws LoadException if the load failed in an expected way
@@ -115,27 +145,20 @@ public interface Loader extends ExtensionPoint, Comparable<Loader> {
 	 * @throws VersionException if the load process tried to open an existing {@link DomainFile} 
 	 *   which was created with a newer or unsupported version of Ghidra
 	 */
-	public LoadResults<? extends DomainObject> load(ByteProvider provider, String loadedName,
-			Project project, String projectFolderPath, LoadSpec loadSpec, List<Option> options,
-			MessageLog messageLog, Object consumer, TaskMonitor monitor) throws IOException,
-			CancelledException, VersionException, LoadException;
+	public LoadResults<? extends DomainObject> load(ImporterSettings settings)
+			throws IOException, CancelledException, VersionException, LoadException;
 
 	/**
 	 * Loads bytes into the specified {@link Program}.  This method will not create any new 
 	 * {@link Program}s.  It is only for adding to an existing {@link Program}.
 	 *
-	 * @param provider The bytes to load into the {@link Program}.
-	 * @param loadSpec The {@link LoadSpec} to use during load.
-	 * @param options The load options.
-	 * @param messageLog The message log.
 	 * @param program The {@link Program} to load into.
-	 * @param monitor A cancelable task monitor.
+	 * @param settings The {@link ImporterSettings}.
 	 * @throws LoadException if the load failed in an expected way.
 	 * @throws IOException if there was an IO-related problem loading.
 	 * @throws CancelledException if the user cancelled the load.
 	 */
-	public void loadInto(ByteProvider provider, LoadSpec loadSpec, List<Option> options,
-			MessageLog messageLog, Program program, TaskMonitor monitor)
+	public void loadInto(Program program, ImporterSettings settings)
 			throws IOException, LoadException, CancelledException;
 
 	/**
@@ -146,10 +169,12 @@ public interface Loader extends ExtensionPoint, Comparable<Loader> {
 	 * @param domainObject The {@link DomainObject} being loaded.
 	 * @param loadIntoProgram True if the load is adding to an existing {@link DomainObject}; 
 	 *   otherwise, false.
+	 * @param mirrorFsLayout True if the filesystem layout should be mirrored when loading;
+	 *   otherwise, false
 	 * @return A list of the {@link Loader}'s default options.
 	 */
 	public List<Option> getDefaultOptions(ByteProvider provider, LoadSpec loadSpec,
-			DomainObject domainObject, boolean loadIntoProgram);
+			DomainObject domainObject, boolean loadIntoProgram, boolean mirrorFsLayout);
 
 	/**
 	 * Validates the {@link Loader}'s options and returns null if all options are valid; otherwise, 
@@ -159,7 +184,7 @@ public interface Loader extends ExtensionPoint, Comparable<Loader> {
 	 * @param loadSpec The proposed {@link LoadSpec}.
 	 * @param options The list of {@link Option}s to validate.
 	 * @param program existing program if the loader is adding to an existing program. If it is
-	 * a fresh import, then this will be null. 
+	 *   a fresh import, then this will be null. 
 	 * @return null if all {@link Option}s are valid; otherwise, an error message describing the 
 	 *   problem is returned.
 	 */
@@ -200,12 +225,13 @@ public interface Loader extends ExtensionPoint, Comparable<Loader> {
 	 * if absolutely necessary.
 	 * 
 	 * @param provider The bytes to load.
-	 * @return The preferred file name to use when loading.
+	 * @return The preferred file name to use when loading, or {@code null} if a name could not
+	 *   be determined from the provider.
 	 */
 	public default String getPreferredFileName(ByteProvider provider) {
 		FSRL fsrl = provider.getFSRL();
 		String name = (fsrl != null) ? fsrl.getName() : provider.getName();
-		return name.replaceAll("[\\\\:|]+", "/");
+		return name != null ? name.replaceAll("[\\\\:|]+", "/") : null;
 	}
 
 	/**
