@@ -1,13 +1,12 @@
 /* ###
  * IP: GHIDRA
- * REVIEWED: YES
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -17,7 +16,8 @@
 package ghidra.app.util.recognizer;
 
 public class CramFSRecognizer implements Recognizer {
-    public String recognize(byte[] bytes) {
+    @Override
+	public String recognize(byte[] bytes) {
         if (bytes.length >= numberOfBytesRequired()) {
             if (bytes[0] == (byte) 0x45 &&
                 bytes[1] == (byte) 0x3d &&
@@ -29,11 +29,13 @@ public class CramFSRecognizer implements Recognizer {
         return null;
     }
 
-    public int getPriority() {
+    @Override
+	public int getPriority() {
         return 100;
     }
 
-    public int numberOfBytesRequired() {
+    @Override
+	public int numberOfBytesRequired() {
         return 4;
     }
 }
