@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -114,19 +114,25 @@ public class FidAnalyzer extends AbstractAnalyzer {
 
 	@Override
 	public boolean getDefaultEnablement(Program program) {
-		return service.canProcess(program.getLanguage());
+		// Loading Fid db files can be slow.  For now, signal that we can analyze and check later.
+		return true;
+		//return service.canProcess(program.getLanguage());
 	}
 
 	@Override
 	public boolean canAnalyze(Program program) {
-		return service.canProcess(program.getLanguage());
+		// Loading Fid db files can be slow.  For now, signal that we can analyze and check later.
+		return true;
+		//return service.canProcess(program.getLanguage());
 	}
 
 	@Override
 	public boolean added(Program program, AddressSetView set, TaskMonitor monitor, MessageLog log)
 			throws CancelledException {
+
 		if (!service.canProcess(program.getLanguage())) {
-			Msg.warn(this, "No FID Libraries apply for language " + program.getLanguageID());
+			// This can now happen, since we no longer check in canAnalyze()
+			Msg.debug(this, "No FID Libraries apply for language " + program.getLanguageID());
 			return false;
 		}
 
