@@ -255,11 +255,9 @@ public class FileSystemService {
 	 * @param fsrl {@link FSRL} of the desired file
 	 * @param monitor {@link TaskMonitor} so the user can cancel
 	 * @return a {@link RefdFile} which contains the resultant {@link GFile} and a
-	 * {@link FileSystemRef} that needs to be closed, or {@code null} if the filesystem
-	 * does not have the requested file.
-	 *
+	 * {@link FileSystemRef} that needs to be closed, never {@code null}
 	 * @throws CancelledException if the user cancels
-	 * @throws IOException if there was a file io problem
+	 * @throws IOException if file not found or there was a file io problem
 	 */
 	public RefdFile getRefdFile(FSRL fsrl, TaskMonitor monitor)
 			throws CancelledException, IOException {
@@ -267,8 +265,8 @@ public class FileSystemService {
 		try {
 			GFile gfile = ref.getFilesystem().lookup(fsrl.getPath());
 			if (gfile == null) {
-				throw new IOException("File [" + fsrl + "] not found in filesystem [" +
-					ref.getFilesystem().getFSRL() + "]");
+				throw new IOException("File [%s] not found in filesystem [%s]"
+						.formatted(fsrl.getPath(), ref.getFilesystem().getFSRL()));
 			}
 			RefdFile result = new RefdFile(ref, gfile);
 			ref = null;
@@ -709,13 +707,6 @@ public class FileSystemService {
 			if (ref != null) {
 				return ref;
 			}
-
-			GFileSystem subdirFS = probeForLocalSubDirFilesystem(containerFSRL);
-			if (subdirFS != null) {
-				ref = subdirFS.getRefManager().create();
-				fsInstanceManager.add(subdirFS);
-				return ref;
-			}
 		}
 
 		// Normal case, probe the container file and create a filesystem instance.
@@ -748,18 +739,6 @@ public class FileSystemService {
 		return null;
 	}
 
-	private GFileSystem probeForLocalSubDirFilesystem(FSRL containerFSRL) {
-		if (localFS.isLocalSubdir(containerFSRL)) {
-			try {
-				return localFS.getSubFileSystem(containerFSRL);
-			}
-			catch (IOException e) {
-				Msg.error(this, "Problem when probing for local directory: ", e);
-			}
-		}
-		return null;
-	}
-	
 	/**
 	 * Mount a specific file system (by class) using a specified container file.
 	 * <p>
@@ -815,11 +794,6 @@ public class FileSystemService {
 	public GFileSystem openFileSystemContainer(FSRL containerFSRL, TaskMonitor monitor)
 			throws CancelledException, IOException {
 
-		GFileSystem subdirFS = probeForLocalSubDirFilesystem(containerFSRL);
-		if (subdirFS != null) {
-			return subdirFS;
-		}
-
 		ByteProvider byteProvider = getByteProvider(containerFSRL, true, monitor);
 		return fsFactoryMgr.probe(byteProvider, this, null, FileSystemInfo.PRIORITY_LOWEST,
 			monitor);
