@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -17,8 +17,7 @@ package ghidra.framework.main;
 
 import java.awt.Component;
 
-import ghidra.framework.model.DomainFileFilter;
-import ghidra.framework.model.Project;
+import ghidra.framework.model.*;
 
 /**
  * Dialog to open or save domain data items to a new location or name.
@@ -33,9 +32,9 @@ public class DataTreeDialog extends AbstractDataTreeDialog {
 
 	/**
 	 * Construct a new DataTreeDialog for the active project.  This chooser will show all project
-	 * files.  Following linked-folders will only be allowed if a type of CHOOSE_FOLDER
-	 * or OPEN is specified.  If different behavior is required a filter should 
-	 * be specified using the other constructor. 
+	 * files and/or folders within the active project only. Broken and external links will not be
+	 * shown.  If different behavior is required a filter should be specified using the other 
+	 * constructor. 
 	 *
 	 * @param parent dialog's parent
 	 * @param title title to use
@@ -43,7 +42,7 @@ public class DataTreeDialog extends AbstractDataTreeDialog {
 	 * @throws IllegalArgumentException if invalid type is specified
 	 */
 	public DataTreeDialog(Component parent, String title, DataTreeDialogType type) {
-		this(parent, title, type, getDefaultFilter(type));
+		this(parent, title, type, DomainFileFilter.ALL_INTERNAL_FILES_FILTER);
 	}
 
 	/**
@@ -52,7 +51,9 @@ public class DataTreeDialog extends AbstractDataTreeDialog {
 	 * @param parent dialog's parent
 	 * @param title title to use
 	 * @param type specify OPEN, SAVE, CHOOSE_FOLDER, or CREATE
-	 * @param filter filter used to control what is displayed in the data tree
+	 * @param filter filter used to control what is displayed in the data tree.  See static
+	 * implementations provided by {@link DomainFileFilter} and a more tailored 
+	 * {@link DefaultDomainFileFilter}.
 	 * @throws IllegalArgumentException if invalid type is specified
 	 */
 	public DataTreeDialog(Component parent, String title, DataTreeDialogType type,
@@ -66,7 +67,9 @@ public class DataTreeDialog extends AbstractDataTreeDialog {
 	 * @param parent dialog's parent
 	 * @param title title to use
 	 * @param type specify OPEN, SAVE, CHOOSE_FOLDER, or CREATE
-	 * @param filter filter used to control what is displayed in the data tree
+	 * @param filter filter used to control what is displayed in the data tree.  See static
+	 * implementations provided by {@link DomainFileFilter} and a more tailored 
+	 * {@link DefaultDomainFileFilter}.
 	 * @param project the project to browse
 	 * @throws IllegalArgumentException if invalid type is specified
 	 */
