@@ -58,23 +58,28 @@ public class ProjectDataDeleteAction extends FrontendProjectTreeAction {
 
 		// Confirm the delete *without* using a task so that do not have 2 dialogs showing
 		int fileCount = countTask.getFileCount();
-		if (!confirmDelete(fileCount, files, context.getComponent())) {
+		if (!confirmDelete(fileCount, files, folders, context.getComponent())) {
 			return;
 		}
 
 		// Task 2 - perform the delete--this could take a while
 		DeleteProjectFilesTask deleteTask = createDeleteTask(context, files, folders, fileCount);
 		TaskLauncher.launch(deleteTask);
-	}
 
+		if (!deleteTask.isCancelled()) {
+			deleteTask.showReport();
+		}
+	}
+	
 	DeleteProjectFilesTask createDeleteTask(ProjectDataContext context, Set<DomainFile> files,
 			Set<DomainFolder> folders, int fileCount) {
 		return new DeleteProjectFilesTask(folders, files, fileCount, context.getComponent());
 	}
 
-	private boolean confirmDelete(int fileCount, Set<DomainFile> files, Component parent) {
+	private boolean confirmDelete(int fileCount, Set<DomainFile> files, Set<DomainFolder> folders,
+			Component parent) {
 
-		String message = getMessage(fileCount, files);
+		String message = getMessage(fileCount, files, folders);
 		OptionDialogBuilder builder = new OptionDialogBuilder("Confirm Delete", message);
 		int choice = builder.addOption("OK")
 				.addCancel()
@@ -83,31 +88,30 @@ public class ProjectDataDeleteAction extends FrontendProjectTreeAction {
 		return choice != OptionDialog.CANCEL_OPTION;
 	}
 
-	private String getMessage(int fileCount, Set<DomainFile> selectedFiles) {
+	private String getMessage(int fileCount, Set<DomainFile> files, Set<DomainFolder> folders) {
 
 		if (fileCount == 0) {
 			return "Are you sure you want to delete the selected empty folder(s)?";
 		}
 
-		if (fileCount == 1) {
-			if (!selectedFiles.isEmpty()) {
-				DomainFile file = CollectionUtils.any(selectedFiles);
-				return "<html>Are you sure you want to <B><U>permanently</U></B> delete \"" +
-					HTMLUtilities.escapeHTML(file.getName()) + "\"?";
+		if (folders.isEmpty()) {
+			if (fileCount == 1) {
+				DomainFile file = CollectionUtils.any(files);
+				String type = file.getContentType();
+				return "<html>Are you sure you want to <B><U>permanently</U></B> delete " + type +
+					" \"" + HTMLUtilities.escapeHTML(file.getName()) + "\"?";
 			}
-
-			// only folders are selected, but they contain files
 			return "<html>Are you sure you want to <B><U>permanently</U></B> delete the " +
-				" selected files and folders?";
+				" selected files?";
 		}
 
 		// multiple files selected
-		return "<html>Are you sure you want to <B><U>permanently</U></B> delete the " + fileCount +
-			" selected files?";
+		return "<html>Are you sure you want to <B><U>permanently</U></B> delete the selected folder(s) and file(s)?";
 	}
 
 	@Override
 	protected boolean isEnabledForContext(ProjectDataContext context) {
+		// NOTE: Folder-links are treated as files
 		if (!context.hasOneOrMoreFilesAndFolders()) {
 			return false;
 		}
