@@ -21,7 +21,8 @@ import org.apache.logging.log4j.LogManager;
 import org.apache.logging.log4j.Logger;
 
 import ghidra.framework.store.*;
-import ghidra.util.*;
+import ghidra.util.Msg;
+import ghidra.util.ReadOnlyException;
 import ghidra.util.exception.*;
 import ghidra.util.task.TaskMonitor;
 import utilities.util.FileUtilities;
@@ -49,7 +50,7 @@ public abstract class LocalFolderItem implements FolderItem {
 
 	static final String DATA_DIR_EXTENSION = ".db";
 
-	final PropertyFile propertyFile;
+	final ItemPropertyFile propertyFile;
 	final CheckoutManager checkoutMgr;
 	final HistoryManager historyMgr;
 	final LocalFileSystem fileSystem;
@@ -69,7 +70,7 @@ public abstract class LocalFolderItem implements FolderItem {
 	 * @param fileSystem file system
 	 * @param propertyFile property file
 	 */
-	LocalFolderItem(LocalFileSystem fileSystem, PropertyFile propertyFile) {
+	LocalFolderItem(LocalFileSystem fileSystem, ItemPropertyFile propertyFile) {
 		this.fileSystem = fileSystem;
 		this.propertyFile = propertyFile;
 		this.isVersioned = fileSystem.isVersioned();
@@ -88,14 +89,14 @@ public abstract class LocalFolderItem implements FolderItem {
 	 * @param useDataDir if true the getDataDir() method must return an appropriate 
 	 * directory for data storage.
 	 * @param create if true the data directory will be created
-	 * @throws IOException
+	 * @throws IOException if an IO error occurs
 	 */
-	LocalFolderItem(LocalFileSystem fileSystem, PropertyFile propertyFile, boolean useDataDir,
+	LocalFolderItem(LocalFileSystem fileSystem, ItemPropertyFile propertyFile, boolean useDataDir,
 			boolean create) throws IOException {
 		this.fileSystem = fileSystem;
 		this.propertyFile = propertyFile;
 		this.isVersioned = fileSystem.isVersioned();
-		this.useDataDir = useDataDir || isVersioned;
+		this.useDataDir = useDataDir;
 
 		boolean success = false;
 		try {
@@ -121,7 +122,7 @@ public abstract class LocalFolderItem implements FolderItem {
 				throw new FileNotFoundException(getName() + " not found");
 			}
 
-			if (isVersioned) {
+			if (isVersioned && useDataDir) {
 				checkoutMgr = new CheckoutManager(this, create);
 				historyMgr = new HistoryManager(this, create);
 			}
@@ -161,7 +162,7 @@ public abstract class LocalFolderItem implements FolderItem {
 	final File getDataDir() {
 		synchronized (fileSystem) {
 			// Use hidden DB directory
-			return new File(propertyFile.getFolder(),
+			return new File(propertyFile.getParentStorageDirectory(),
 				LocalFileSystem.HIDDEN_DIR_PREFIX +
 					LocalFileSystem.escapeHiddenDirPrefixChars(propertyFile.getStorageName()) +
 					DATA_DIR_EXTENSION);
@@ -234,6 +235,9 @@ public abstract class LocalFolderItem implements FolderItem {
 	 */
 	void beginCheckin(long checkoutId) throws FileInUseException {
 		synchronized (fileSystem) {
+			if (checkoutMgr == null) {
+				throw new UnsupportedOperationException("item does not support checkin/checkout");
+			}
 			if (checkinId != DEFAULT_CHECKOUT_ID) {
 				ItemCheckoutStatus status;
 				try {
@@ -426,7 +430,7 @@ public abstract class LocalFolderItem implements FolderItem {
 		synchronized (fileSystem) {
 			checkInUse();
 
-			File oldFolder = propertyFile.getFolder();
+			File oldFolder = propertyFile.getParentStorageDirectory();
 			String oldStorageName = propertyFile.getStorageName();
 			String oldPath = propertyFile.getParentPath();
 			File oldDbDir = getDataDir();
@@ -491,41 +495,6 @@ public abstract class LocalFolderItem implements FolderItem {
 		return propertyFile.getName();
 	}
 
-//	/**
-//	 * Change the name of this item's property file and hidden data directory
-//	 * based upon the new item name.
-//	 * If in-use files prevent renaming a FileInUseException will be thrown.
-//	 * @param name new name for this item
-//	 * @throws InvalidNameException invalid name was specified
-//	 * @throws IOException an error occurred
-//	 */
-//	void doSetName(String name) throws InvalidNameException, IOException {
-//		synchronized (fileSystem) {
-//			File oldDbDir = getDataDir();
-//			String oldName = getName();
-//
-//			boolean success = false;
-//			try {
-//				propertyFile.setName(name);
-//				File newDbDir = getDataDir();
-//				if (useDataDir) {
-//					if (newDbDir.exists()) {
-//						throw new DuplicateFileException(getName() + " already exists");
-//					}
-//					else if (!oldDbDir.renameTo(newDbDir)) {
-//						throw new FileInUseException(oldName + " is in use");
-//					}
-//				}
-//				success = true;
-//			}
-//			finally {
-//				if (!success && !propertyFile.getName().equals(oldName)) {
-//					propertyFile.setName(oldName);
-//				}
-//			}
-//		}
-//	}
-
 	/**
 	 * @see ghidra.framework.store.FolderItem#getParentPath()
 	 */
@@ -590,6 +559,10 @@ public abstract class LocalFolderItem implements FolderItem {
 				throw new UnsupportedOperationException(
 					"Non-versioned item does not support getVersions");
 			}
+			if (historyMgr == null) {
+				throw new UnsupportedOperationException(
+					"getVersions not supported without history manager");
+			}
 			return historyMgr.getVersions();
 		}
 	}
@@ -652,12 +625,16 @@ public abstract class LocalFolderItem implements FolderItem {
 	@Override
 	public ItemCheckoutStatus checkout(CheckoutType checkoutType, String user, String projectPath)
 			throws IOException {
+		if (checkoutMgr == null) {
+			throw new UnsupportedOperationException("item does not support checkin/checkout");
+		}
 		if (!isVersioned) {
 			throw new UnsupportedOperationException("Non-versioned item does not support checkout");
 		}
 		if (fileSystem.isReadOnly()) {
 			throw new ReadOnlyException();
 		}
+
 		synchronized (fileSystem) {
 
 			ItemCheckoutStatus coStatus =
@@ -672,6 +649,9 @@ public abstract class LocalFolderItem implements FolderItem {
 
 	@Override
 	public void terminateCheckout(long checkoutId, boolean notify) throws IOException {
+		if (checkoutMgr == null) {
+			throw new UnsupportedOperationException("item does not support checkin/checkout");
+		}
 		if (!isVersioned) {
 			throw new UnsupportedOperationException("Non-versioned item does not support checkout");
 		}
@@ -700,6 +680,9 @@ public abstract class LocalFolderItem implements FolderItem {
 				throw new UnsupportedOperationException(
 					"Non-versioned item does not support checkout");
 			}
+			if (checkoutMgr == null) {
+				return null;
+			}
 			return checkoutMgr.getCheckout(checkoutId);
 		}
 	}
@@ -711,6 +694,9 @@ public abstract class LocalFolderItem implements FolderItem {
 				throw new UnsupportedOperationException(
 					"Non-versioned item does not support checkout");
 			}
+			if (checkoutMgr == null) {
+				return new ItemCheckoutStatus[0];
+			}
 			return checkoutMgr.getAllCheckouts();
 		}
 	}
@@ -802,33 +788,39 @@ public abstract class LocalFolderItem implements FolderItem {
 	 * @param propertyFile property file which identifies the folder item.
 	 * @return folder item
 	 */
-	static LocalFolderItem getFolderItem(LocalFileSystem fileSystem, PropertyFile propertyFile) {
+	static LocalFolderItem getFolderItem(LocalFileSystem fileSystem,
+			ItemPropertyFile propertyFile) {
 		int fileType = propertyFile.getInt(FILE_TYPE, UNKNOWN_FILE_TYPE);
 		try {
 			if (fileType == DATAFILE_FILE_TYPE) {
-				return new LocalDataFile(fileSystem, propertyFile);
+				return new LocalDataFileItem(fileSystem, propertyFile);
 			}
 			else if (fileType == DATABASE_FILE_TYPE) {
 				return new LocalDatabaseItem(fileSystem, propertyFile);
 			}
+			else if (fileType == LINK_FILE_TYPE) {
+				return new LocalTextDataItem(fileSystem, propertyFile);
+			}
 			else if (fileType == UNKNOWN_FILE_TYPE) {
-				log.error("Folder item has unspecified file type: " +
-					new File(propertyFile.getFolder(), propertyFile.getStorageName()));
+				log.error("Folder item has unspecified file type: " + new File(
+					propertyFile.getParentStorageDirectory(), propertyFile.getStorageName()));
 			}
 			else {
-				log.error("Folder item has unsupported file type (" + fileType + "): " +
-					new File(propertyFile.getFolder(), propertyFile.getStorageName()));
+				log.error("Folder item has unsupported file type (" + fileType + "): " + new File(
+					propertyFile.getParentStorageDirectory(), propertyFile.getStorageName()));
 			}
 		}
 		catch (FileNotFoundException e) {
 			log.error("Folder item may be corrupt due to missing file: " +
-				new File(propertyFile.getFolder(), propertyFile.getStorageName()), e);
+				new File(propertyFile.getParentStorageDirectory(), propertyFile.getStorageName()),
+				e);
 		}
 		catch (IOException e) {
 			log.error("Folder item may be corrupt: " +
-				new File(propertyFile.getFolder(), propertyFile.getStorageName()), e);
+				new File(propertyFile.getParentStorageDirectory(), propertyFile.getStorageName()),
+				e);
 		}
-		return new UnknownFolderItem(fileSystem, propertyFile);
+		return new LocalUnknownFolderItem(fileSystem, propertyFile);
 	}
 
 	@Override
@@ -836,7 +828,7 @@ public abstract class LocalFolderItem implements FolderItem {
 		synchronized (fileSystem) {
 			if (isVersioned) {
 				try {
-					return checkoutMgr.isCheckedOut();
+					return checkoutMgr != null && checkoutMgr.isCheckedOut();
 				}
 				catch (IOException e) {
 					Msg.error(getName() + " versioning error", e);
@@ -865,6 +857,11 @@ public abstract class LocalFolderItem implements FolderItem {
 		return false;
 	}
 
+	@Override
+	public int hashCode() {
+		return propertyFile.hashCode();
+	}
+
 	/**
 	 * Update this non-versioned item with the latest version of the specified versioned item.
 	 * @param versionedFolderItem versioned item which corresponds to this
@@ -892,6 +889,9 @@ public abstract class LocalFolderItem implements FolderItem {
 	@Override
 	public void updateCheckoutVersion(long checkoutId, int checkoutVersion, String user)
 			throws IOException {
+		if (checkoutMgr == null) {
+			throw new UnsupportedOperationException("item does not support checkin/checkout");
+		}
 		if (!isVersioned) {
 			throw new UnsupportedOperationException(
 				"updateCheckoutVersion is not applicable to non-versioned item");
@@ -907,4 +907,5 @@ public abstract class LocalFolderItem implements FolderItem {
 			checkoutMgr.updateCheckout(checkoutId, checkoutVersion);
 		}
 	}
+
 }
