@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -66,10 +66,10 @@ import ghidra.app.script.GhidraScript;
 import ghidra.app.services.Analyzer;
 import ghidra.app.services.GraphDisplayBroker;
 import ghidra.app.util.NamespaceUtils;
-import ghidra.app.util.bin.format.dwarf4.next.DWARFFunctionImporter;
-import ghidra.app.util.bin.format.dwarf4.next.DWARFProgram;
-import ghidra.app.util.bin.format.dwarf4.next.sectionprovider.DWARFSectionProvider;
-import ghidra.app.util.bin.format.dwarf4.next.sectionprovider.DWARFSectionProviderFactory;
+import ghidra.app.util.bin.format.dwarf.DWARFFunctionImporter;
+import ghidra.app.util.bin.format.dwarf.DWARFProgram;
+import ghidra.app.util.bin.format.dwarf.sectionprovider.DWARFSectionProvider;
+import ghidra.app.util.bin.format.dwarf.sectionprovider.DWARFSectionProviderFactory;
 import ghidra.app.util.bin.format.pdb.PdbParserConstants;
 import ghidra.app.util.importer.MessageLog;
 import ghidra.app.util.opinion.PeLoader;
@@ -80,8 +80,9 @@ import ghidra.program.model.data.*;
 import ghidra.program.model.listing.*;
 import ghidra.program.model.mem.MemoryBlock;
 import ghidra.program.model.reloc.Relocation;
+import ghidra.program.model.reloc.Relocation.Status;
 import ghidra.program.model.reloc.RelocationTable;
-import ghidra.program.model.symbol.Symbol;
+import ghidra.program.model.symbol.*;
 import ghidra.program.util.GhidraProgramUtilities;
 import ghidra.service.graph.*;
 import ghidra.util.exception.CancelledException;
@@ -119,9 +120,12 @@ public class RecoverClassesFromRTTIScript extends GhidraScript {
 	// They are either undefined bytes or code that is not in a function. 
 	private static final boolean FIXUP_PROGRAM = true;
 
-	// bookmark all constructor/destructor functions figured out by this script
+	// bookmark all constructor/destructor functions recognized by script
 	private static final boolean BOOKMARK_FOUND_FUNCTIONS = true;
 
+	// make vfunctions this calls
+	private static final boolean MAKE_VFUNCTIONS_THISCALLS = true;
+
 	// show a graph of class hierarchies after script is complete
 	// no parent = blue vertex
 	// single parent = green vertex
@@ -190,10 +194,9 @@ public class RecoverClassesFromRTTIScript extends GhidraScript {
 
 			hasDebugSymbols = isPDBLoadedInProgram();
 			nameVfunctions = !hasDebugSymbols;
-			recoverClassesFromRTTI =
-				new RTTIWindowsClassRecoverer(currentProgram, currentLocation, state.getTool(),
-					this, BOOKMARK_FOUND_FUNCTIONS, USE_SHORT_TEMPLATE_NAMES_IN_STRUCTURE_FIELDS,
-					nameVfunctions, hasDebugSymbols, monitor);
+			recoverClassesFromRTTI = new RTTIWindowsClassRecoverer(currentProgram, state.getTool(),
+				this, BOOKMARK_FOUND_FUNCTIONS, USE_SHORT_TEMPLATE_NAMES_IN_STRUCTURE_FIELDS,
+				nameVfunctions, MAKE_VFUNCTIONS_THISCALLS, hasDebugSymbols, monitor);
 		}
 		else if (isPE() && isGcc()) {
 
@@ -211,12 +214,10 @@ public class RecoverClassesFromRTTIScript extends GhidraScript {
 			if (!runGcc) {
 				return;
 			}
-			//run fixup old elf relocations script
-			runScript("FixElfExternalOffsetDataRelocationScript.java");
-			recoverClassesFromRTTI =
-				new RTTIGccClassRecoverer(currentProgram, currentLocation, state.getTool(), this,
-					BOOKMARK_FOUND_FUNCTIONS, USE_SHORT_TEMPLATE_NAMES_IN_STRUCTURE_FIELDS,
-					nameVfunctions, hasDebugSymbols, monitor);
+
+			recoverClassesFromRTTI = new RTTIGccClassRecoverer(currentProgram, state.getTool(),
+				this, BOOKMARK_FOUND_FUNCTIONS, USE_SHORT_TEMPLATE_NAMES_IN_STRUCTURE_FIELDS,
+				nameVfunctions, MAKE_VFUNCTIONS_THISCALLS, hasDebugSymbols, monitor);
 		}
 		else if (isGcc()) {
 
@@ -234,9 +235,6 @@ public class RecoverClassesFromRTTIScript extends GhidraScript {
 				return;
 			}
 
-			//run fixup old elf relocations script
-			runScript("FixElfExternalOffsetDataRelocationScript.java");
-
 			hasDebugSymbols = isDwarfLoadedInProgram();
 			if (hasDwarf() && !hasDebugSymbols) {
 				println(
@@ -245,10 +243,9 @@ public class RecoverClassesFromRTTIScript extends GhidraScript {
 				return;
 			}
 			nameVfunctions = !hasDebugSymbols;
-			recoverClassesFromRTTI =
-				new RTTIGccClassRecoverer(currentProgram, currentLocation, state.getTool(), this,
-					BOOKMARK_FOUND_FUNCTIONS, USE_SHORT_TEMPLATE_NAMES_IN_STRUCTURE_FIELDS,
-					nameVfunctions, hasDebugSymbols, monitor);
+			recoverClassesFromRTTI = new RTTIGccClassRecoverer(currentProgram, state.getTool(),
+				this, BOOKMARK_FOUND_FUNCTIONS, USE_SHORT_TEMPLATE_NAMES_IN_STRUCTURE_FIELDS,
+				nameVfunctions, MAKE_VFUNCTIONS_THISCALLS, hasDebugSymbols, monitor);
 		}
 		else {
 			println("This script will not work on this program type");
@@ -329,12 +326,9 @@ public class RecoverClassesFromRTTIScript extends GhidraScript {
 			getNumberOfConstructorsOrDestructors(recoveredClasses) +
 			" class member functions to assign.");
 
-		if (!hasDebugSymbols) {
-
-			if (BOOKMARK_FOUND_FUNCTIONS) {
-				bookmarkFunctions(recoveredClasses);
-				println("See Bookmark Manager for a list of functions by type.");
-			}
+		if (BOOKMARK_FOUND_FUNCTIONS) {
+			bookmarkFunctions(recoveredClasses);
+			println("See Bookmark Manager for a list of functions by type.");
 		}
 
 		callOptionalOutputMethods(recoveredClasses, out);
@@ -382,7 +376,7 @@ public class RecoverClassesFromRTTIScript extends GhidraScript {
 			DWARFProgram.DWARF_ROOT_NAME) || options.getBoolean("DWARF Loaded", false));
 	}
 
-	public String validate() throws CancelledException {
+	public String validate() throws Exception {
 
 		if (currentProgram == null) {
 			return ("There is no open program");
@@ -390,7 +384,7 @@ public class RecoverClassesFromRTTIScript extends GhidraScript {
 
 		if (!GhidraProgramUtilities.isAnalyzed(currentProgram)) {
 			return ("The program has not been analyzed. Please run auto-analysis and make sure " +
-				"the RTTI analzer is one of the analyzers enabled.");
+				"the RTTI analyzer is one of the analyzers enabled.");
 		}
 
 		if (isRttiAnalyzed() && !hasRtti()) {
@@ -420,9 +414,11 @@ public class RecoverClassesFromRTTIScript extends GhidraScript {
 		// check that gcc loader or mingw analyzer has fixed the relocations correctly
 		if (isGcc()) {
 
+			runScript("FixElfExternalOffsetDataRelocationScript.java");
+
 			// first check that there is even rtti by searching the special string in memory
-			if (!isStringInProgramMemory("class_type_info")) {
-				return ("This program does not contain RTTI.");
+			if (!isStringInProgramMemory("class_type_info") && !containsClassTypeinfoSymbol()) {
+				return ("This program does not appear to contain RTTI.");
 			}
 
 			// then check to see if the special typeinfo namespace is in external space
@@ -435,7 +431,7 @@ public class RecoverClassesFromRTTIScript extends GhidraScript {
 					"contact the Ghidra team so this issue can be fixed.");
 			}
 
-			if (hasUnhandledRelocations()) {
+			if (hasRelocationIssue()) {
 				return ("This program has unhandled elf relocations so cannot continue. Please " +
 					"contact the Ghidra team for assistance.");
 			}
@@ -445,7 +441,13 @@ public class RecoverClassesFromRTTIScript extends GhidraScript {
 
 	}
 
-	private boolean hasUnhandledRelocations() throws CancelledException {
+	/**
+	 * Method to determine if the gcc relocations needed to find the special typeinfos/vtables 
+	 * have any issues that would keep script from running correctly.
+	 * @return true if there are any issues with the relocations, false otherwise
+	 * @throws CancelledException if cancelled
+	 */
+	private boolean hasRelocationIssue() throws CancelledException {
 
 		RelocationTable relocationTable = currentProgram.getRelocationTable();
 
@@ -455,13 +457,35 @@ public class RecoverClassesFromRTTIScript extends GhidraScript {
 			monitor.checkCancelled();
 			Relocation r = relocations.next();
 
-			if (r.getSymbolName().contains("class_type_info") &&
-				(r.getStatus() != Relocation.Status.APPLIED &&
-					r.getStatus() != Relocation.Status.APPLIED_OTHER &&
-					r.getStatus() != Relocation.Status.SKIPPED)) {
-				return true;
-			}
+			String symbolName = r.getSymbolName();
 
+			if (symbolName != null && symbolName.contains("class_type_info")) {
+
+				Status status = r.getStatus();
+
+				// if any relocations for special typeinfo class symbols have failed then there
+				// is an issue
+				if (status == Status.FAILURE) {
+					return true;
+				}
+
+				// if any relocations for special typeinfo class symbols are unsupported then
+				// determine where the symbol is located before determining if it is an issue
+				if (status == Status.UNSUPPORTED) {
+
+					//if relocation symbol is the same as the symbol at the relcation address
+					//then this situation is not an issue - it indicates a copy relocation at the
+					//location of the special typeinfo vtable which is a use case that can be handled
+					Address address = r.getAddress();
+					Symbol symbolAtAddress = currentProgram.getSymbolTable()
+							.getSymbol(symbolName, address, currentProgram.getGlobalNamespace());
+					if (symbolAtAddress != null) {
+						continue;
+					}
+					return true;
+				}
+
+			}
 		}
 		return false;
 	}
@@ -1591,9 +1615,25 @@ public class RecoverClassesFromRTTIScript extends GhidraScript {
 		return false;
 	}
 
+	// assume that if there are any symbols containing "class_type_info" there is rtti in program
+	private boolean containsClassTypeinfoSymbol() {
+
+		SymbolTable symbolTable = currentProgram.getSymbolTable();
+		SymbolIterator symbolIterator =
+			symbolTable.getSymbolIterator("*class_type_info*", true);
+		return symbolIterator.hasNext();
+
+	}
+
 	private boolean isExternalNamespace(String path) throws CancelledException {
 
-		List<Symbol> symbols = NamespaceUtils.getSymbols(path, currentProgram, true);
+		// try exact namespace path if there is one
+		List<Symbol> symbols = NamespaceUtils.getSymbols(path, currentProgram, false);
+
+		// if not, try to find path in another namespace
+		if (symbols.isEmpty()) {
+			symbols = NamespaceUtils.getSymbols(path, currentProgram, true);
+		}
 
 		for (Symbol symbol : symbols) {
 			monitor.checkCancelled();
