@@ -1530,6 +1530,29 @@ Varnode *VarnodeBank::findCoveringInput(int4 s,const Address &loc) const
   return (Varnode *)0;
 }
 
+/// \param s is the number of bytes in the given range
+/// \param loc is the starting address of the given range
+/// \return \b true if there is an input Varnode that overlaps the range
+bool VarnodeBank::hasInputIntersection(int4 s,const Address &loc) const
+
+{
+  VarnodeDefSet::const_iterator iter;
+  Varnode *vn;
+  iter = beginDef(Varnode::input,loc);
+  if (iter != def_tree.end()) {
+    vn = *iter;
+    if (vn->isInput() && vn->intersects(loc, s))
+      return true;
+  }
+  if (iter != def_tree.begin()) {
+    --iter;
+    vn = *iter;
+    if (vn->isInput() && vn->intersects(loc,s))
+      return true;
+  }
+  return false;
+}
+
 /// \brief Beginning of Varnodes in given address space sorted by location
 ///
 /// \param spaceid is the given address space
@@ -1983,36 +2006,6 @@ void VarnodeBank::verifyIntegrity(void) const
 }
 #endif
 
-/// \brief Return \b true if the alternate path looks more valid than the main path.
-///
-/// Two different paths from a common Varnode each terminate at a CALL, CALLIND, or RETURN.
-/// Evaluate which path most likely represents actual parameter/return value passing,
-/// based on traversal information about each path.
-/// \param vn is the Varnode terminating the \e alternate path
-/// \param flags indicates traversals for both paths
-/// \return \b true if the alternate path is preferred
-bool TraverseNode::isAlternatePathValid(const Varnode *vn,uint4 flags)
-
-{
-  if ((flags & (indirect | indirectalt)) == indirect)
-    // If main path traversed an INDIRECT but the alternate did not
-    return true;	// Main path traversed INDIRECT, alternate did not
-  if ((flags & (indirect | indirectalt)) == indirectalt)
-    return false;	// Alternate path traversed INDIRECT, main did not
-  if ((flags & actionalt) != 0)
-    return true;	// Alternate path traversed a dedicated COPY
-  if (vn->loneDescend() == (PcodeOp*)0) return false;
-  const PcodeOp *op = vn->getDef();
-  if (op == (PcodeOp*)0) return true;
-  while(op->isIncidentalCopy() && op->code() == CPUI_COPY) {	// Skip any incidental COPY
-    vn = op->getIn(0);
-    if (vn->loneDescend() == (PcodeOp *)0) return false;
-    op = vn->getDef();
-    if (op == (PcodeOp *)0) return true;
-  }
-  return !op->isMarker();	// MULTIEQUAL or INDIRECT indicates multiple values
-}
-
 /// Return true if \b vn1 contains the high part and \b vn2 the low part
 /// of what was(is) a single value.
 /// \param vn1 is the putative high Varnode
